import processing.serial.*;

Serial arduinoPort; // Serial port for communication with Arduino
boolean servoMoved = false; // Flag to track servo position
Button servoButton; // Declare the button

void setup() {
  size(400, 200);
  String[] portNames = Serial.list();
  if (portNames.length > 0) {
    arduinoPort = new Serial(this, portNames[0], 9600); // Change baud rate if needed
  } else {
    println("No Arduino port found. Make sure it's connected.");
    noLoop();
  }

  // Create the button
  servoButton = new Button(width / 2 - 50, height / 2 - 20, 100, 40, "Move Servo");
  servoButton.onClick(() -> {
    if (!servoMoved) {
      arduinoPort.write("90"); // Send "90" to Arduino
      servoMoved = true;
    } else {
      arduinoPort.write("0"); // Send "0" to return servo to initial position
      servoMoved = false;
    }
  });
}

void draw() {
  background(220);
  // Display the button
  servoButton.display();
}

class Button {
  float x, y, w, h;
  String label;
  Runnable onClickAction;

  Button(float x, float y, float w, float h, String label) {
    this.x = x;
    this.y = y;
    this.w = w;
    this.h = h;
    this.label = label;
  }

  void display() {
    // Button appearance
    fill(255);
    stroke(0);
    rect(x, y, w, h, 10); // Rounded corners
    fill(0);
    textAlign(CENTER, CENTER);
    textSize(16);
    text(label, x + w / 2, y + h / 2);
  }

  void onClick(Runnable action) {
    onClickAction = action;
  }

  void checkClick(float mx, float my) {
    if (mx > x && mx < x + w && my > y && my < y + h) {
      onClickAction.run();
    }
  }
}

void mousePressed() {
  servoButton.checkClick(mouseX, mouseY);
}
